"""
info: TCR_numba
"""

__version__ = "0.1.0"
__author__ = "Paul Richter"
__credits__ = "ETH Zurich"

from . import graph_numba
#from . import make_net
from . import convert_pure
